@@ -4,14 +4,16 @@ from uuid import UUID, uuid4
 
 from slapp_py.core_classes.battlefy import Battlefy
 from slapp_py.core_classes.discord import Discord
-from slapp_py.core_classes.friend_code import FriendCode
+from slapp_py.core_classes.friend_code_handler import FriendCodeHandler
 from slapp_py.core_classes.name import Name
+from slapp_py.core_classes.pronoun import Pronoun
 from slapp_py.core_classes.skill import Skill
 from slapp_py.core_classes.socials.plus_membership import PlusMembership
 from slapp_py.core_classes.socials.sendou import Sendou
 from slapp_py.core_classes.socials.twitch import Twitch
 from slapp_py.core_classes.socials.twitter import Twitter
-from slapp_py.helpers.dict_helper import from_list, to_list, deserialize_uuids, serialize_uuids
+from slapp_py.core_classes.teams_handler import TeamsHandler
+from slapp_py.helpers.dict_helper import from_list, to_list
 
 
 class Player:
@@ -27,7 +29,7 @@ class Player:
     discord: Discord
     """Back-store for player's Discord information."""
 
-    friend_codes: List[FriendCode]
+    fc_information: FriendCodeHandler
     """Back-store for player's FCs."""
 
     names: List[Name]
@@ -42,8 +44,8 @@ class Player:
     sendou_profiles: List[Sendou]
     """Back-store for the Sendou Profiles of this player."""
 
-    teams: List[UUID]
-    """Back-store for the team GUIDs for this player. The first element is the current team.
+    teams_information: TeamsHandler
+    """Back-store for the team IDs for this player. The first element is the current team.
     No team represented by Team.NoTeam.Id."""
 
     top500: bool
@@ -63,10 +65,10 @@ class Player:
 
     def __init__(self,
                  names: Union[None, Name, List[Name], str, List[str]] = None,
-                 teams: Union[None, UUID, List[UUID]] = None,
+                 teams_information: Optional[TeamsHandler] = None,
                  battlefy: Optional[Battlefy] = None,
                  discord: Optional[Discord] = None,
-                 friend_codes: Optional[List[FriendCode]] = None,
+                 fc_information: Optional[FriendCodeHandler] = None,
                  skill: Optional[Skill] = None,
                  plus_membership: Optional[List[PlusMembership]] = None,
                  sendou_profiles: Optional[List[Sendou]] = None,
@@ -75,6 +77,7 @@ class Player:
                  weapons: Optional[List[str]] = None,
                  country: Optional[str] = None,
                  top500: bool = False,
+                 pronoun: Optional[Pronoun] = None,
                  guid: Union[None, str, UUID] = None):
         # When adding params please update filter_to_source
 
@@ -92,20 +95,10 @@ class Player:
             else:
                 logging.error(f"player: Can't handle {names[i]} -- expected Name or str. Ignoring.")
 
-        if not teams:
-            self.teams = []
-        else:
-            if not isinstance(teams, list):
-                teams = [teams]
-
-            self.teams = []
-            for i in range(0, len(teams)):
-                assert isinstance(teams[i], UUID)
-                self.teams.append(teams[i])
-
+        self.teams_information = teams_information or TeamsHandler()
         self.battlefy = battlefy or Battlefy()
         self.discord = discord or Discord()
-        self.friend_codes = friend_codes or []
+        self.fc_information = fc_information or FriendCodeHandler()
         self.skill = skill or Skill()
         self.plus_membership = plus_membership or []
         self.sendou_profiles = sendou_profiles or []
@@ -114,6 +107,7 @@ class Player:
         self.weapons = weapons or []
         self.country = country.upper() if country and len(country) == 2 else None
         self.top500 = top500
+        self.pronoun = pronoun
 
         if isinstance(guid, str):
             guid = UUID(guid)
@@ -140,14 +134,14 @@ class Player:
         return (sorted(self.plus_membership, key=lambda pm: pm.date)[-1]) if self.plus_membership else None
 
     def filter_to_source(self, source_id: Union[str, UUID]) -> 'Player':
-        """Filter this Player instance down to the components made by a source id."""
+        """Filter this Player instance down to the components made by a sources id."""
         search_uuid = source_id if isinstance(source_id, UUID) else UUID(source_id)
         return Player(
             names=[name for name in self.names if search_uuid in name.sources],
-            teams=self.teams,  # TODO - teams don't have associated Sources at this level. Needs adding.
-            battlefy=self.battlefy.filter_to_source(source_id),
-            discord=self.discord.filter_to_source(source_id),
-            friend_codes=self.friend_codes,  # TODO - FCs don't have associated Sources at this level. Needs adding.
+            teams_information=self.teams_information.filter_to_source(search_uuid),
+            battlefy=self.battlefy.filter_to_source(search_uuid),
+            discord=self.discord.filter_to_source(search_uuid),
+            fc_information=self.fc_information.filter_to_source(search_uuid),
             skill=None,
             plus_membership=[name for name in self.plus_membership if search_uuid in name.sources],
             sendou_profiles=[name for name in self.sendou_profiles if search_uuid in name.sources],
@@ -156,6 +150,7 @@ class Player:
             weapons=None,
             country=self.country,
             top500=self.top500,
+            pronoun=self.pronoun if self.pronoun.source == search_uuid else None,
             guid=self.guid)
 
     @property
@@ -173,7 +168,10 @@ class Player:
                             + [x.sources for x in self.battlefy.slugs]
                             + [x.sources for x in self.battlefy.usernames]
                             + [x.sources for x in self.discord.ids]
-                            + [x.sources for x in self.discord.usernames], [])
+                            + [x.sources for x in self.discord.usernames]
+                            + [self.fc_information.get_sources_flat()]
+                            + [self.teams_information.get_sources_flat()]
+                            + [[self.pronoun.source]], [])
                     ),
                     reverse=True
                 )
@@ -185,12 +183,13 @@ class Player:
         return Player(
             battlefy=Battlefy.from_dict(obj.get("Battlefy")) if "Battlefy" in obj else None,
             discord=Discord.from_dict(obj.get("Discord")) if "Discord" in obj else None,
-            friend_codes=from_list(lambda x: FriendCode.from_dict(x), obj.get("FCs")),
+            fc_information=FriendCodeHandler.from_dict(obj.get("FCs")) if "FCs" in obj else None,
             names=from_list(lambda x: Name.from_dict(x), obj.get("N")),
+            pronoun=Pronoun.from_dict(obj.get("Pro")),
             plus_membership=from_list(lambda x: PlusMembership.from_dict(x), obj.get("Plus")),
             sendou_profiles=from_list(lambda x: Sendou.from_dict(x), obj.get("Sendou")),
             skill=Skill.from_dict(obj.get("Skill")) if "Skill" in obj else Skill(),
-            teams=deserialize_uuids(obj, "Teams"),
+            teams_information=TeamsHandler.from_dict(obj.get("Teams")) if "Teams" in obj else None,
             twitch_profiles=from_list(lambda x: Twitch.from_dict(x), obj.get("Twitch")),
             twitter_profiles=from_list(lambda x: Twitter.from_dict(x), obj.get("Twitter")),
             weapons=from_list(lambda x: str(x), obj.get("Weapons")),
@@ -207,19 +206,21 @@ class Player:
             result["Country"] = self.country
         if len(self.discord.ids) > 0 or len(self.discord.usernames) > 0:
             result["Discord"] = self.discord.to_dict()
-        if len(self.friend_codes) > 0:
-            result["FCs"] = to_list(lambda x: FriendCode.to_dict(x), self.friend_codes)
+        if self.fc_information.count > 0:
+            result["FCs"] = self.fc_information.to_dict()
         result["Id"] = self.guid.__str__()
         if len(self.names) > 0:
             result["N"] = to_list(lambda x: Name.to_dict(x), self.names)
         if len(self.plus_membership) > 0:
             result["Plus"] = to_list(lambda x: PlusMembership.to_dict(x), self.plus_membership)
+        if self.pronoun:
+            result["Pro"] = self.pronoun.to_dict()
         if len(self.sendou_profiles) > 0:
             result["Sendou"] = to_list(lambda x: Sendou.to_dict(x), self.sendou_profiles)
         if not self.skill.is_default:
             result["Skill"] = self.skill.to_dict(),
-        if len(self.teams) > 0:
-            result["Teams"] = serialize_uuids(self.teams)
+        if self.teams_information.count > 0:
+            result["Teams"] = self.teams_information.to_dict()
         if self.top500:
             result["Top500"] = self.top500
         if len(self.twitch_profiles) > 0:
@@ -240,8 +241,7 @@ class Player:
 
         result = players[0]
         for player in players[1:]:
-            result.teams.extend(player.teams)
-            result.teams = list(set(result.teams))
+            result.teams_information.merge(player.teams_information)
 
             result.names.extend(player.names)
             result.names = list(set(result.names))
@@ -276,8 +276,7 @@ class Player:
             result.twitter_profiles.extend(player.twitter_profiles)
             result.twitter_profiles = list(set(result.twitter_profiles))
 
-            result.friend_codes.extend(player.friend_codes)
-            result.friend_codes = list(set(result.friend_codes))
+            result.fc_information.merge(player.fc_information)
 
             if player.country and result.country != player.country:
                 result.country = player.country
