@@ -9,7 +9,7 @@ from slapp_py.core_classes.team import Team
 from slapp_py.helpers.dict_helper import to_list, from_list, deserialize_uuids
 
 UNKNOWN_SOURCE = "(Unnamed Source)"
-"""Displayed string for an unknown source."""
+"""Displayed string for an unknown sources."""
 
 UNKNOWN_DATE_TIME = datetime.utcfromtimestamp(0)
 """The unknown datetime (epoch)"""
@@ -41,7 +41,7 @@ class Source:
 
     @property
     def tournament_id(self) -> str:
-        """Get the tournament id from the source name. This substrings past the last -."""
+        """Get the tournament id from the sources name. This substrings past the last -."""
         # rpartition finds the last '-', we want the substring past that to the end which is [2].
         return self.name.rpartition('-')[2]
 
