@@ -5,6 +5,7 @@ from uuid import UUID, uuid4
 from slapp_py.core_classes import division
 from slapp_py.core_classes.clan_tag import ClanTag
 from slapp_py.core_classes.division import Division
+from slapp_py.core_classes.divisions_handler import DivisionsHandler
 from slapp_py.core_classes.name import Name
 from slapp_py.core_classes.socials.battlefy_team_social import BattlefyTeamSocial
 from slapp_py.core_classes.socials.twitter import Twitter
@@ -18,8 +19,8 @@ class Team:
     clan_tags: List[ClanTag] = []
     """The tag(s) of the team, first is the current tag."""
 
-    divisions: List[Division] = []
-    """The division(s) of the team, first is the current."""
+    division_information: DivisionsHandler
+    """The division(s) of the team."""
 
     names: List[Name] = []
     """Back-store for the names of this team. The first element is the current name."""
@@ -33,13 +34,13 @@ class Team:
     def __init__(self,
                  battlefy_persistent_team_ids: Optional[List[BattlefyTeamSocial]] = None,
                  clan_tags: Optional[List[ClanTag]] = None,
-                 divisions: Optional[List[Division]] = None,
+                 division_information: Optional[DivisionsHandler] = None,
                  names: Union[None, Name, List[Name], str, List[str]] = None,
                  twitter_profiles: Optional[List[Twitter]] = None,
                  guid: Union[None, str, UUID] = None):
         self.battlefy_persistent_team_ids = battlefy_persistent_team_ids or []
         self.clan_tags = list(set(clan_tags or []))
-        self.divisions = divisions or []
+        self.division_information = division_information or DivisionsHandler()
 
         if not names:
             self.names = []
@@ -88,7 +89,7 @@ class Team:
     @property
     def current_div(self) -> Division:
         """The most recent division of the team or Division.Unknown."""
-        return self.divisions[0] if len(self.divisions) > 0 else division.Unknown
+        return self.division_information.current_div
 
     @property
     def div_history(self) -> str:
@@ -96,7 +97,7 @@ class Team:
         if self.current_div.is_unknown:
             return ""
         else:
-            return ' ⬅ '.join([d.__str__() for d in self.divisions[:3]])
+            return ' ⬅ '.join([d.__str__() for d in self.division_information.get_divs_unordered()[:3]])
 
     @property
     def sources(self):
@@ -125,7 +126,7 @@ class Team:
             battlefy_persistent_team_ids=from_list(lambda x: BattlefyTeamSocial.from_dict(x),
                                                    obj.get("BattlefyPersistentTeamIds")),
             clan_tags=from_list(lambda x: ClanTag.from_dict(x), obj.get("ClanTags")),
-            divisions=from_list(lambda x: Division.from_dict(x), obj.get("Divisions")),
+            division_information=DivisionsHandler.from_dict(obj.get("Divisions")),
             names=from_list(lambda x: Name.from_dict(x), obj.get("N")),
             twitter_profiles=from_list(lambda x: Twitter.from_dict(x), obj.get("Twitter")),
             guid=UUID(obj.get("Id"))
@@ -138,8 +139,8 @@ class Team:
                                                           self.battlefy_persistent_team_ids)
         if len(self.clan_tags) > 0:
             result["ClanTags"] = to_list(lambda x: ClanTag.to_dict(x), self.clan_tags)
-        if len(self.divisions) > 0:
-            result["Divisions"] = to_list(lambda x: Division.to_dict(x), self.divisions)
+        if self.division_information.count > 0:
+            result["Divisions"] = self.division_information.to_dict()
         result["Id"] = self.guid.__str__()
         if len(self.names) > 0:
             result["N"] = to_list(lambda x: Name.to_dict(x), self.names)
@@ -153,8 +154,8 @@ class Team:
             return self.current_div
         else:
             best_div = division.Unknown
-            last_n_divisions = min(last_n_divisions, len(self.divisions))  # Can only be up to the size.
-            for div in self.divisions[:last_n_divisions]:
+            last_n_divisions = min(last_n_divisions, self.division_information.count)  # Can only be up to the size.
+            for div in self.division_information.get_divs_unordered()[:last_n_divisions]:
                 if div < best_div:
                     best_div = div
             return best_div
