@@ -127,10 +127,10 @@ class SlappResponseObject:
         return self.get_teams_from_ids([team_id])[0]
 
     def get_teams_for_player(self, p: Player) -> List[Team]:
-        return [self.get_team(t_uuid) for t_uuid in p.teams]
+        return [self.get_team(t_uuid) for t_uuid in p.teams_information.get_teams_unordered()]
 
     def get_best_team_for_player(self, p: Player) -> Team:
-        return self.get_best_team_by_div([self.get_team(t_uuid) for t_uuid in p.teams])
+        return self.get_best_team_by_div([self.get_team(t_uuid) for t_uuid in p.teams_information.get_teams_unordered()])
 
     def get_team_skills(self, team_guid: Union[UUID, str], include_ex_players: bool = True) -> Dict[Player, Skill]:
         """
@@ -195,13 +195,13 @@ class SlappResponseObject:
 
     def get_brackets_for_player(self, p: Player) -> Dict[str, List[Bracket]]:
         """
-        Gets the brackets for the specified player in a dictionary keyed by the source id and its brackets.
+        Gets the brackets for the specified player in a dictionary keyed by the sources id and its brackets.
         """
         return self.placements_for_players.get(p.guid.__str__(), {})
 
     def get_brackets_for_player_by_source(self, p: Player, source_id: str) -> List[Bracket]:
         """
-        Gets the brackets for the specified player for the source specified as a flat list.
+        Gets the brackets for the specified player for the sources specified as a flat list.
         """
         return self.get_brackets_for_player(p).get(source_id.__str__(), [])
 
