@@ -32,9 +32,9 @@ async def _receive_slapp_response(success_message: str, response: dict):
 
 def load_sources_yaml_file(path: Optional[str] = None):
     """
-    Load the yaml sources file - this is in the format of one source file to load per line.
+    Load the yaml sources file - this is in the format of one sources file to load per line.
     :param path: The sources file path. Do not specify to use the latest default.
-    :return: The contents of the sources file - expected a list of source file paths.
+    :return: The contents of the sources file - expected a list of sources file paths.
     If the file path doesn't exist, None is returned.
     """
     if not path:
@@ -82,7 +82,7 @@ def generate_new_sources_files(battlefy_ids: Collection[str], skip_redownload: b
 
     # Sources now that we've pulled in the tourney files:
     # Dictionary keyed by ids with values of path,
-    # and if the source is new since the current source (true) or was present in the last sources file (false)
+    # and if the sources is new since the current sources (true) or was present in the last sources file (false)
     processed_tourney_ids: Dict[str, Tuple[str, bool]] = {}
     for tourney_id in battlefy_ids:
         # Search the sources yaml
@@ -303,14 +303,14 @@ def add_tourney_placement_to_source(tourney_id: str,
         print(f'No stages found in {tourney_id=}.')
         return False
 
-    # Find the suitable source in the latest sources snapshot
+    # Find the suitable sources in the latest sources snapshot
     source = get_source_by_tourney_id(tourney_id, sources)
     if not source:
-        print(f"Could not find a source in the snapshot that matches {tourney_id=}. Not adding.")
+        print(f"Could not find a sources in the snapshot that matches {tourney_id=}. Not adding.")
         return False
 
     if source.brackets and source.brackets[0].is_valid and source.brackets[-1].is_valid:
-        print(f"Brackets already exist for this source. Skipping.")
+        print(f"Brackets already exist for this sources. Skipping.")
         return False
 
     _global_player_local_id_to_slapp_id.clear()
